summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJiwoong Im <jiwoong.im@samsung.com>2015-11-06 15:09:13 +0900
committerJiwoong Im <jiwoong.im@samsung.com>2015-11-06 15:09:13 +0900
commit30b414f5faebbfaf407ced68783b4987d3ec74e2 (patch)
tree192966ba6aef1a7407fd21d08bfb5db6b4a0d6dd
parentd762357a69f3185955ff427e5f2c443572111604 (diff)
downloadsettings-tizen.tar.gz
settings-tizen.tar.bz2
settings-tizen.zip
Change-Id: I467275ba20d7449f03e3539844963a1e119aba22 Signed-off-by: Jiwoong Im <jiwoong.im@samsung.com>
-rw-r--r--src/main.c38
-rw-r--r--src/view_uigadget.c2
-rw-r--r--ug/channel/src/ug_auto_program.c40
-rw-r--r--ug/network/src/ug_network_settings.c56
-rw-r--r--ug/proxy/src/ug_proxy_settings.c56
-rw-r--r--ug/system/clock/src/ug_clock.c8
-rw-r--r--ug/wifi-direct/src/ug_wifi_direct.c32
7 files changed, 117 insertions, 115 deletions
diff --git a/src/view_uigadget.c b/src/view_uigadget.c
index 7a722a8..bd63cb3 100644
--- a/src/view_uigadget.c
+++ b/src/view_uigadget.c
@@ -86,7 +86,7 @@ static void _ug_layout_cb(ui_gadget_h ug, enum ug_mode mode, void *priv)
* @param priv [in] The function specific data passed by UG caller.
* @return void.
*/
-static void _ug_result_cb(ui_gadget_h ug, service_h result, void *priv)
+static void _ug_result_cb(ui_gadget_h ug, app_control_h result, void *priv)
{
}
diff --git a/src/main.c b/src/main.c
index c833162..bb58312 100644
--- a/src/main.c
+++ b/src/main.c
@@ -192,11 +192,11 @@ static void _resume(void *data)
* This callback is invoked after _create callback (just after app enters main loop)
* or after "re-launch".
*
* @param service [in] The launching arguments.
* @param data [in] The function specific data passed by app_efl_main.
* @return void.
*/
-static void _service(service_h service, void *data)
+static void _app_control(app_control_h app_control, void *data)
{
struct _appdata *ad;
struct setting_mgr *mgr;
@@ -211,7 +211,7 @@ static void _service(service_h service, void *data)
param = NULL;
if (ad->service) {
- service_get_extra_data(service, PARAM_SETTINGS_ITEM, &param);
+ app_control_get_extra_data(app_control, PARAM_SETTINGS_ITEM, &param);
if ((!param && !ad->item) ||
(param && ad->item &&
!strcmp(ad->item, param))) {
@@ -236,8 +236,8 @@ static void _service(service_h service, void *data)
if (!mgr)
app_efl_exit();
- r = service_get_extra_data(service, PARAM_SETTINGS_ITEM, &param);
- if (r == SERVICE_ERROR_NONE && param) {
+ r = app_control_get_extra_data(app_control, PARAM_SETTINGS_ITEM, &param);
+ if (r == APP_CONTROL_ERROR_NONE && param) {
r = settingmgr_launch_item(mgr, param);
if (r != 0) {
_ERR("the item is not exist.");
@@ -300,25 +300,27 @@ static void _region_changed(void *data)
int main(int argc, char **argv)
{
struct _appdata ad;
- app_event_callback_s cbs = {
- .create = _create,
- .terminate = _terminate,
- .pause = _pause,
- .resume = _resume,
- .service = _service,
- .low_memory = NULL,
- .low_battery = NULL,
- .device_orientation = NULL,
- .language_changed = _lang_changed,
- .region_format_changed = _region_changed,
- };
+
+ ui_app_lifecycle_callback_s event_callback = { 0, };
+ app_event_handler_h handlers[5] = { NULL, };
+
+ event_callback.create = _create;
+ event_callback.terminate = _terminate;
+ event_callback.pause = _pause;
+ event_callback.resume = _resume;
+ event_callback.app_control = _app_control;
+
+ ui_app_add_event_handler(&handlers[APP_EVENT_LANGUAGE_CHANGED],
+ APP_EVENT_LANGUAGE_CHANGED, _lang_changed, &ad);
+ ui_app_add_event_handler(&handlers[APP_EVENT_REGION_FORMAT_CHANGED],
+ APP_EVENT_REGION_FORMAT_CHANGED, _region_changed, &ad);
memset(&ad, 0x00, sizeof(ad));
ad.name = PACKAGE;
i18n_init();
- app_efl_main(&argc, &argv, &cbs, &ad);
+ ui_app_main(argc, argv, &event_callback, &ad);
return 0;
}
@@ -192,11 +192,11 @@ static void _resume(void *data)
* or after "re-launch".
*
-* @param service [in] The launching arguments.
+* @param app_control [in] The launching arguments.
* @param data [in] The function specific data passed by app_efl_main.
* @return void.
diff --git a/ug/channel/src/ug_auto_program.c b/ug/channel/src/ug_auto_program.c
index 6097aa6..6818d07 100644
--- a/ug/channel/src/ug_auto_program.c
+++ b/ug/channel/src/ug_auto_program.c
@@ -40,8 +40,8 @@
*
* @param[in] ug: The channel ui gadget object being created
* @param[in] mode: Mode of UI gadget (UG_MODE_FULLVIEW | UG_MODE_FRAMEVIEW)
* @param[in] service: The handler to the service.
* Each operation will receive this service type data, and the argument service
* is automatically released by UI gadget manager after the UI gadget
* is destroyed.
* @priv[in] priv: The user data passed from the callback registration function.
@@ -49,7 +49,7 @@
* @return the base layout
*/
static void *_on_create(ui_gadget_h ug, enum ug_mode mode,
- service_h service, void *priv)
+ app_control_h app_control, void *priv)
{
Evas_Object *win;
struct _ugdata *ugd;
@@ -99,15 +99,15 @@ static void *_on_create(ui_gadget_h ug, enum ug_mode mode,
* so just describe additional job you need to do in this operation.
*
* @param[in] ug: The channel ui gadget object being created
* @param[in] service: The handler to the service.
* Each operation will receive this service type data, and the argument service
* is automatically released by UI gadget manager after the UI gadget
* is destroyed.
* @priv[in] priv: The user data passed from the callback registration function.
*
* There is no action in this function.
*/
-static void _on_start(ui_gadget_h ug, service_h service, void *priv)
+static void _on_start(ui_gadget_h ug, app_control_h app_control, void *priv)
{
}
@@ -115,12 +115,12 @@ static void _on_start(ui_gadget_h ug, service_h service, void *priv)
* Pause channel ug.
*
* @param[in] ug: The channel ui gadget object being created
-* @param[in] service: The handler to the service.
+* @param[in] app_control: The handler to the app_control.
* @priv[in] priv: The user data passed from the callback registration function.
*
* There is no action in this function.
*/
-static void _on_pause(ui_gadget_h ug, service_h service, void *priv)
+static void _on_pause(ui_gadget_h ug, app_control_h app_control, void *priv)
{
}
@@ -128,12 +128,12 @@ static void _on_pause(ui_gadget_h ug, service_h service, void *priv)
* Resume channel ug.
*
* @param[in] ug: The channel ui gadget object being created
-* @param[in] service: The handler to the service.
+* @param[in] app_control: The handler to the app_control.
* @priv[in] priv: The user data passed from the callback registration function.
*
* There is no action in this function.
*/
-static void _on_resume(ui_gadget_h ug, service_h service, void *priv)
+static void _on_resume(ui_gadget_h ug, app_control_h app_control, void *priv)
{
}
@@ -146,10 +146,10 @@ static void _on_resume(ui_gadget_h ug, service_h service, void *priv)
* the viewmgr will be released.
*
* @param[in] ug: The channel ui gadget object
-* @param[in] service: The handler to the service.
+* @param[in] app_control: The handler to the app_control.
* @priv[in] priv: The user data passed from the callback registration function.
*/
-static void _on_destroy(ui_gadget_h ug, service_h service, void *priv)
+static void _on_destroy(ui_gadget_h ug, app_control_h app_control, void *priv)
{
struct _ugdata *ugd;
@@ -170,17 +170,17 @@ static void _on_destroy(ui_gadget_h ug, service_h service, void *priv)
* the message operation on_message is invoked.
*
* @param[in] ug: The channel ui gadget object
* @param[in] msg: The handler to the service data.
* Each operation will receive this service type data,
* And the argument service is automatically released by UI gadget manager
* after the UI gadget is destroyed
-* @param[in] service: The handler to the service.
+* @param[in] app_control: The handler to the app_control.
* @priv[in] priv: The user data passed from the callback registration function.
*
* There is no action in this function.
*/
-static void _on_message(ui_gadget_h ug, service_h msg,
- service_h service, void *priv)
+static void _on_message(ui_gadget_h ug, app_control_h msg,
+ app_control_h app_control, void *priv)
{
}
@@ -190,11 +190,11 @@ static void _on_message(ui_gadget_h ug, service_h msg,
*
* @param[in] ug: The channel ui gadget object
* @param[in] event: The event for channel ui gadget
-* @param[in] service: The handler to the service.
+* @param[in] app_control: The handler to the app_control.
* @priv[in] priv: The user data passed from the callback registration function.
*/
static void _on_event(ui_gadget_h ug, enum ug_event event,
- service_h service, void *priv)
+ app_control_h app_control, void *priv)
{
if (!ug || !priv)
return;
@@ -40,8 +40,8 @@
* @param[in] ug: The channel ui gadget object being created
* @param[in] mode: Mode of UI gadget (UG_MODE_FULLVIEW | UG_MODE_FRAMEVIEW)
-* @param[in] service: The handler to the service.
-* Each operation will receive this service type data, and the argument service
+* @param[in] app_control: The handler to the app_control.
+* Each operation will receive this app_control type data, and the argument app_control
* is automatically released by UI gadget manager after the UI gadget
* is destroyed.
@@ -99,15 +99,15 @@ static void *_on_create(ui_gadget_h ug, enum ug_mode mode,
*
* @param[in] ug: The channel ui gadget object being created
-* @param[in] service: The handler to the service.
-* Each operation will receive this service type data, and the argument service
+* @param[in] app_control: The handler to the app_control.
+* Each operation will receive this app_control type data, and the argument app_control
* is automatically released by UI gadget manager after the UI gadget
* is destroyed.
@@ -170,17 +170,17 @@ static void _on_destroy(ui_gadget_h ug, service_h service, void *priv)
*
* @param[in] ug: The channel ui gadget object
-* @param[in] msg: The handler to the service data.
-* Each operation will receive this service type data,
-* And the argument service is automatically released by UI gadget manager
+* @param[in] msg: The handler to the app_control data.
+* Each operation will receive this app_control type data,
+* And the argument app_control is automatically released by UI gadget manager
* after the UI gadget is destroyed
diff --git a/ug/network/src/ug_network_settings.c b/ug/network/src/ug_network_settings.c
index f3f38dc..ff6a935 100644
--- a/ug/network/src/ug_network_settings.c
+++ b/ug/network/src/ug_network_settings.c
@@ -45,16 +45,16 @@ struct _ug_data {
*
* @param[in] ug The network ui gadget object being created
* @param[in] mode Mode of UI gadget (UG_MODE_FULLVIEW | UG_MODE_FRAMEVIEW)
* @param[in] service Each operation will receive this service type data,
* (see \ref service_PG "Tizen Managed APi Reference Guide >
* Application Framework -> Application") And the argument <i>service</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
*
* @return the base layout
*/
static void *_on_create(ui_gadget_h ug, enum ug_mode mode,
- service_h service, void *priv)
+ app_control_h app_control, void *priv)
{
struct _ug_data *ugd;
Evas_Object *base;
@@ -111,15 +111,15 @@ static void *_on_create(ui_gadget_h ug, enum ug_mode mode,
* so just describe additional job you need to do in this operation.
*
* @param[in] ug The network ui gadget object being created
* @param[in] service Each operation will receive this service type data,
* (see \ref service_PG "Tizen Managed APi Reference Guide >
* Application Framework -> Application") And the argument <i>service</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
*
* There is no action in this function.
*/
-static void _on_start(ui_gadget_h ug, service_h service, void *priv)
+static void _on_start(ui_gadget_h ug, app_control_h app_control, void *priv)
{
}
@@ -127,15 +127,15 @@ static void _on_start(ui_gadget_h ug, service_h service, void *priv)
* Pause network ug.
*
* @param[in] ug The network ui gadget object being created
* @param[in] service Each operation will receive this service type data,
* (see \ref service_PG "Tizen Managed APi Reference Guide >
* Application Framework -> Application") And the argument <i>service</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
*
* There is no action in this function.
*/
-static void _on_pause(ui_gadget_h ug, service_h service, void *priv)
+static void _on_pause(ui_gadget_h ug, app_control_h app_control, void *priv)
{
}
@@ -143,15 +143,15 @@ static void _on_pause(ui_gadget_h ug, service_h service, void *priv)
* Resume network ug.
*
* @param[in] ug The network ui gadget object being created
* @param[in] service Each operation will receive this service type data,
* (see \ref service_PG "Tizen Managed APi Reference Guide >
* Application Framework -> Application") And the argument <i>service</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
*
* There is no action in this function.
*/
-static void _on_resume(ui_gadget_h ug, service_h service, void *priv)
+static void _on_resume(ui_gadget_h ug, app_control_h app_control, void *priv)
{
}
@@ -164,13 +164,13 @@ static void _on_resume(ui_gadget_h ug, service_h service, void *priv)
* the viewmgr will be released.
*
* @param[in] ug the network ui gadget object
* @param[in] service each operation will receive this service type data,
* (see \ref service_PG "Tizen Managed APi Reference Guide >
* Application Framework -> Application") And the argument <i>service</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv the data structure
*/
-static void _on_destroy(ui_gadget_h ug, service_h service, void *priv)
+static void _on_destroy(ui_gadget_h ug, app_control_h app_control, void *priv)
{
struct _ug_data *ugd = priv;
@@ -190,16 +190,16 @@ static void _on_destroy(ui_gadget_h ug, service_h service, void *priv)
* the message operation on_message is invoked.
*
* @param[in] ug The network ui gadget object being created
* @param[in] service Each operation will receive this service type data,
* (see \ref service_PG "Tizen Managed APi Reference Guide >
* Application Framework -> Application") And the argument <i>service</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
*
* There is no action in this function.
*/
static void _on_message(ui_gadget_h ug,
- service_h msg, service_h service, void *priv)
+ app_control_h msg, app_control_h app_control, void *priv)
{
}
@@ -209,14 +209,14 @@ static void _on_message(ui_gadget_h ug,
*
* @param[in] ug the network ui gadget object
* @param[in] event the network ui gadget object
* @param[in] service each operation will receive this service type data,
* (see \ref service_PG "Tizen Managed APi Reference Guide >
* Application Framework -> Application") And the argument <i>service</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv the data structure
*/
static void _on_event(ui_gadget_h ug,
- enum ug_event event, service_h service, void *priv)
+ enum ug_event event, app_control_h app_control, void *priv)
{
if (!ug || !priv) {
_ERR("Parameter error!");
@@ -45,16 +45,16 @@ struct _ug_data {
* @param[in] ug The network ui gadget object being created
* @param[in] mode Mode of UI gadget (UG_MODE_FULLVIEW | UG_MODE_FRAMEVIEW)
-* @param[in] service Each operation will receive this service type data,
-* (see \ref service_PG "Tizen Managed APi Reference Guide >
-* Application Framework -> Application") And the argument <i>service</i> is
+* @param[in] app_control Each operation will receive this app_control type data,
+* (see \ref app_control_PG "Tizen Managed APi Reference Guide >
+* Application Framework -> Application") And the argument <i>app_control</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
@@ -111,15 +111,15 @@ static void *_on_create(ui_gadget_h ug, enum ug_mode mode,
*
* @param[in] ug The network ui gadget object being created
-* @param[in] service Each operation will receive this service type data,
-* (see \ref service_PG "Tizen Managed APi Reference Guide >
-* Application Framework -> Application") And the argument <i>service</i> is
+* @param[in] app_control Each operation will receive this app_control type data,
+* (see \ref app_control_PG "Tizen Managed APi Reference Guide >
+* Application Framework -> Application") And the argument <i>app_control</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
@@ -127,15 +127,15 @@ static void _on_start(ui_gadget_h ug, service_h service, void *priv)
*
* @param[in] ug The network ui gadget object being created
-* @param[in] service Each operation will receive this service type data,
-* (see \ref service_PG "Tizen Managed APi Reference Guide >
-* Application Framework -> Application") And the argument <i>service</i> is
+* @param[in] app_control Each operation will receive this app_control type data,
+* (see \ref app_control_PG "Tizen Managed APi Reference Guide >
+* Application Framework -> Application") And the argument <i>app_control</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
@@ -143,15 +143,15 @@ static void _on_pause(ui_gadget_h ug, service_h service, void *priv)
*
* @param[in] ug The network ui gadget object being created
-* @param[in] service Each operation will receive this service type data,
-* (see \ref service_PG "Tizen Managed APi Reference Guide >
-* Application Framework -> Application") And the argument <i>service</i> is
+* @param[in] app_control Each operation will receive this app_control type data,
+* (see \ref app_control_PG "Tizen Managed APi Reference Guide >
+* Application Framework -> Application") And the argument <i>app_control</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
@@ -164,13 +164,13 @@ static void _on_resume(ui_gadget_h ug, service_h service, void *priv)
*
* @param[in] ug the network ui gadget object
-* @param[in] service each operation will receive this service type data,
-* (see \ref service_PG "Tizen Managed APi Reference Guide >
-* Application Framework -> Application") And the argument <i>service</i> is
+* @param[in] app_control each operation will receive this app_control type data,
+* (see \ref app_control_PG "Tizen Managed APi Reference Guide >
+* Application Framework -> Application") And the argument <i>app_control</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv the data structure
@@ -190,16 +190,16 @@ static void _on_destroy(ui_gadget_h ug, service_h service, void *priv)
*
* @param[in] ug The network ui gadget object being created
-* @param[in] service Each operation will receive this service type data,
-* (see \ref service_PG "Tizen Managed APi Reference Guide >
-* Application Framework -> Application") And the argument <i>service</i> is
+* @param[in] app_control Each operation will receive this app_control type data,
+* (see \ref app_control_PG "Tizen Managed APi Reference Guide >
+* Application Framework -> Application") And the argument <i>app_control</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
@@ -209,14 +209,14 @@ static void _on_message(ui_gadget_h ug,
* @param[in] ug the network ui gadget object
* @param[in] event the network ui gadget object
-* @param[in] service each operation will receive this service type data,
-* (see \ref service_PG "Tizen Managed APi Reference Guide >
-* Application Framework -> Application") And the argument <i>service</i> is
+* @param[in] app_control each operation will receive this app_control type data,
+* (see \ref app_control_PG "Tizen Managed APi Reference Guide >
+* Application Framework -> Application") And the argument <i>app_control</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv the data structure
diff --git a/ug/proxy/src/ug_proxy_settings.c b/ug/proxy/src/ug_proxy_settings.c
index 6ddb58c..c85cc95 100644
--- a/ug/proxy/src/ug_proxy_settings.c
+++ b/ug/proxy/src/ug_proxy_settings.c
@@ -42,16 +42,16 @@ struct _ug_data {
*
* @param[in] ug The proxy ui gadget object being created
* @param[in] mode Mode of UI gadget (UG_MODE_FULLVIEW | UG_MODE_FRAMEVIEW)
* @param[in] service Each operation will receive this service type data,
* (see \ref service_PG "Tizen Managed APi Reference Guide >
* Application Framework -> Application") And the argument <i>service</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
*
* @return the base layout
*/
static void *_on_create(ui_gadget_h ug, enum ug_mode mode,
- service_h service, void *priv)
+ app_control_h app_control, void *priv)
{
struct _ug_data *ugd;
Evas_Object *base;
@@ -97,15 +97,15 @@ static void *_on_create(ui_gadget_h ug, enum ug_mode mode,
* so just describe additional job you need to do in this operation.
*
* @param[in] ug The proxy ui gadget object being created
* @param[in] service Each operation will receive this service type data,
* (see \ref service_PG "Tizen Managed APi Reference Guide >
* Application Framework -> Application") And the argument <i>service</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
*
* There is no action in this function.
*/
-static void _on_start(ui_gadget_h ug, service_h service, void *priv)
+static void _on_start(ui_gadget_h ug, app_control_h app_control, void *priv)
{
}
@@ -113,15 +113,15 @@ static void _on_start(ui_gadget_h ug, service_h service, void *priv)
* Pause proxy ug.
*
* @param[in] ug The proxy ui gadget object being created
* @param[in] service Each operation will receive this service type data,
* (see \ref service_PG "Tizen Managed APi Reference Guide >
* Application Framework -> Application") And the argument <i>service</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
*
* There is no action in this function.
*/
-static void _on_pause(ui_gadget_h ug, service_h service, void *priv)
+static void _on_pause(ui_gadget_h ug, app_control_h app_control, void *priv)
{
}
@@ -129,15 +129,15 @@ static void _on_pause(ui_gadget_h ug, service_h service, void *priv)
* Resume proxy ug.
*
* @param[in] ug The proxy ui gadget object being created
* @param[in] service Each operation will receive this service type data,
* (see \ref service_PG "Tizen Managed APi Reference Guide >
* Application Framework -> Application") And the argument <i>service</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
*
* There is no action in this function.
*/
-static void _on_resume(ui_gadget_h ug, service_h service, void *priv)
+static void _on_resume(ui_gadget_h ug, app_control_h app_control, void *priv)
{
}
@@ -150,13 +150,13 @@ static void _on_resume(ui_gadget_h ug, service_h service, void *priv)
* the viewmgr will be released.
*
* @param[in] ug the proxy ui gadget object
* @param[in] service each operation will receive this service type data,
* (see \ref service_PG "Tizen Managed APi Reference Guide >
* Application Framework -> Application") And the argument <i>service</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv the data structure
*/
-static void _on_destroy(ui_gadget_h ug, service_h service, void *priv)
+static void _on_destroy(ui_gadget_h ug, app_control_h app_control, void *priv)
{
struct _ug_data *ugd = priv;
@@ -176,16 +176,16 @@ static void _on_destroy(ui_gadget_h ug, service_h service, void *priv)
* the message operation on_message is invoked.
*
* @param[in] ug The proxy ui gadget object being created
* @param[in] service Each operation will receive this service type data,
* (see \ref service_PG "Tizen Managed APi Reference Guide >
* Application Framework -> Application") And the argument <i>service</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
*
* There is no action in this function.
*/
static void _on_message(ui_gadget_h ug,
- service_h msg, service_h service, void *priv)
+ app_control_h msg, app_control_h app_control, void *priv)
{
}
@@ -195,14 +195,14 @@ static void _on_message(ui_gadget_h ug,
*
* @param[in] ug the proxy ui gadget object
* @param[in] event the proxy ui gadget object
* @param[in] service each operation will receive this service type data,
* (see \ref service_PG "Tizen Managed APi Reference Guide >
* Application Framework -> Application") And the argument <i>service</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv the data structure
*/
static void _on_event(ui_gadget_h ug,
- enum ug_event event, service_h service, void *priv)
+ enum ug_event event, app_control_h app_control, void *priv)
{
if (!ug || !priv) {
_ERR("Parameter error!");
@@ -42,16 +42,16 @@ struct _ug_data {
* @param[in] ug The proxy ui gadget object being created
* @param[in] mode Mode of UI gadget (UG_MODE_FULLVIEW | UG_MODE_FRAMEVIEW)
-* @param[in] service Each operation will receive this service type data,
-* (see \ref service_PG "Tizen Managed APi Reference Guide >
-* Application Framework -> Application") And the argument <i>service</i> is
+* @param[in] app_control Each operation will receive this app_control type data,
+* (see \ref app_control_PG "Tizen Managed APi Reference Guide >
+* Application Framework -> Application") And the argument <i>app_control</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
@@ -97,15 +97,15 @@ static void *_on_create(ui_gadget_h ug, enum ug_mode mode,
*
* @param[in] ug The proxy ui gadget object being created
-* @param[in] service Each operation will receive this service type data,
-* (see \ref service_PG "Tizen Managed APi Reference Guide >
-* Application Framework -> Application") And the argument <i>service</i> is
+* @param[in] app_control Each operation will receive this app_control type data,
+* (see \ref app_control_PG "Tizen Managed APi Reference Guide >
+* Application Framework -> Application") And the argument <i>app_control</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
@@ -113,15 +113,15 @@ static void _on_start(ui_gadget_h ug, service_h service, void *priv)
*
* @param[in] ug The proxy ui gadget object being created
-* @param[in] service Each operation will receive this service type data,
-* (see \ref service_PG "Tizen Managed APi Reference Guide >
-* Application Framework -> Application") And the argument <i>service</i> is
+* @param[in] app_control Each operation will receive this app_control type data,
+* (see \ref app_control_PG "Tizen Managed APi Reference Guide >
+* Application Framework -> Application") And the argument <i>app_control</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
@@ -129,15 +129,15 @@ static void _on_pause(ui_gadget_h ug, service_h service, void *priv)
*
* @param[in] ug The proxy ui gadget object being created
-* @param[in] service Each operation will receive this service type data,
-* (see \ref service_PG "Tizen Managed APi Reference Guide >
-* Application Framework -> Application") And the argument <i>service</i> is
+* @param[in] app_control Each operation will receive this app_control type data,
+* (see \ref app_control_PG "Tizen Managed APi Reference Guide >
+* Application Framework -> Application") And the argument <i>app_control</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
@@ -150,13 +150,13 @@ static void _on_resume(ui_gadget_h ug, service_h service, void *priv)
*
* @param[in] ug the proxy ui gadget object
-* @param[in] service each operation will receive this service type data,
-* (see \ref service_PG "Tizen Managed APi Reference Guide >
-* Application Framework -> Application") And the argument <i>service</i> is
+* @param[in] app_control each operation will receive this app_control type data,
+* (see \ref app_control_PG "Tizen Managed APi Reference Guide >
+* Application Framework -> Application") And the argument <i>app_control</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv the data structure
@@ -176,16 +176,16 @@ static void _on_destroy(ui_gadget_h ug, service_h service, void *priv)
*
* @param[in] ug The proxy ui gadget object being created
-* @param[in] service Each operation will receive this service type data,
-* (see \ref service_PG "Tizen Managed APi Reference Guide >
-* Application Framework -> Application") And the argument <i>service</i> is
+* @param[in] app_control Each operation will receive this app_control type data,
+* (see \ref app_control_PG "Tizen Managed APi Reference Guide >
+* Application Framework -> Application") And the argument <i>app_control</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv The data structure
@@ -195,14 +195,14 @@ static void _on_message(ui_gadget_h ug,
* @param[in] ug the proxy ui gadget object
* @param[in] event the proxy ui gadget object
-* @param[in] service each operation will receive this service type data,
-* (see \ref service_PG "Tizen Managed APi Reference Guide >
-* Application Framework -> Application") And the argument <i>service</i> is
+* @param[in] app_control each operation will receive this app_control type data,
+* (see \ref app_control_PG "Tizen Managed APi Reference Guide >
+* Application Framework -> Application") And the argument <i>app_control</i> is
* automatically released by UI gadget manager after the UI gadget is destroyed.
* @priv[in] priv the data structure
diff --git a/ug/system/clock/src/ug_clock.c b/ug/system/clock/src/ug_clock.c
index 72ef6fb..2e51567 100644
--- a/ug/system/clock/src/ug_clock.c
+++ b/ug/system/clock/src/ug_clock.c
@@ -869,13 +869,13 @@ static int _add_clock_sublist(struct _ug_data *data)
*
* @param[in]: ug : the UI gadget created by ug_create().
* @param[in]: mode : the mode of ug, fullview or frameview.
* @param[in]: service : argument for the UI gadget.
* @param[in]: priv : the user data.
*
* @return: The base layout of this UI gadget.
*/
static void *_on_create(ui_gadget_h ug,
- enum ug_mode mode, service_h service, void *priv)
+ enum ug_mode mode, app_control_h app_control, void *priv)
{
struct _ug_data *data;
Evas_Object *win;
@@ -948,12 +948,12 @@ static void *_on_create(ui_gadget_h ug,
* This function destroyes all the UI components of this UI gadget.
*
* @param[in]: ug : UI gadget.
* @param[in]: service : argument of this UI gadget.
* @param[in]: priv : the user data.
*
* @return: void.
*/
-static void _on_destroy(ui_gadget_h ug, service_h service, void *priv)
+static void _on_destroy(ui_gadget_h ug, app_control_h app_control, void *priv)
{
struct _ug_data *data;
@@ -869,13 +869,13 @@ static int _add_clock_sublist(struct _ug_data *data)
* @param[in]: ug : the UI gadget created by ug_create().
* @param[in]: mode : the mode of ug, fullview or frameview.
-* @param[in]: service : argument for the UI gadget.
+* @param[in]: app_control : argument for the UI gadget.
* @param[in]: priv : the user data.
*
@@ -948,12 +948,12 @@ static void *_on_create(ui_gadget_h ug,
*
* @param[in]: ug : UI gadget.
-* @param[in]: service : argument of this UI gadget.
+* @param[in]: app_control : argument of this UI gadget.
* @param[in]: priv : the user data.
*
diff --git a/ug/wifi-direct/src/ug_wifi_direct.c b/ug/wifi-direct/src/ug_wifi_direct.c
index 6a5d359..9139fe6 100644
--- a/ug/wifi-direct/src/ug_wifi_direct.c
+++ b/ug/wifi-direct/src/ug_wifi_direct.c
@@ -40,11 +40,11 @@ struct _ug_data {
*
* @param[in] ug UI gadget object
* @param[in] mode mode of UI gadget
-* @param[in] service the handler to the service
+* @param[in] app_control the handler to the app_control
* @param[in] priv _priv object
*/
static void *_on_create(ui_gadget_h ug, enum ug_mode mode,
- service_h service, void *priv)
+ app_control_h app_control, void *priv)
{
struct _ug_data *ugd;
Evas_Object *base;
@@ -86,12 +86,12 @@ static void *_on_create(ui_gadget_h ug, enum ug_mode mode,
* Called when wifi direct ug starts.
*
* @param[in] ug UI gadget object
-* @param[in] service the handler to the service
+* @param[in] app_control the handler to the app_control
* @param[in] priv _priv object
*
* There is no action in this function.
*/
-static void _on_start(ui_gadget_h ug, service_h service, void *priv)
+static void _on_start(ui_gadget_h ug, app_control_h app_control, void *priv)
{
}
@@ -99,12 +99,12 @@ static void _on_start(ui_gadget_h ug, service_h service, void *priv)
* Invoked on pause state of UI Gadget
*
* @param[in] ug UI gadget object
-* @param[in] service the handler to the service
+* @param[in] app_control the handler to the app_control
* @param[in] priv _priv object
*
* There is no action in this application
*/
-static void _on_pause(ui_gadget_h ug, service_h service, void *priv)
+static void _on_pause(ui_gadget_h ug, app_control_h app_control, void *priv)
{
}
@@ -112,12 +112,12 @@ static void _on_pause(ui_gadget_h ug, service_h service, void *priv)
* Invoked on resume state of UI Gadget
*
* @param[in] ug UI gadget object
-* @param[in] service the handler to the service
+* @param[in] app_control the handler to the app_control
* @param[in] priv _priv object
*
* There is no action in this application
*/
-static void _on_resume(ui_gadget_h ug, service_h service, void *priv)
+static void _on_resume(ui_gadget_h ug, app_control_h app_control, void *priv)
{
}
@@ -125,12 +125,12 @@ static void _on_resume(ui_gadget_h ug, service_h service, void *priv)
* Invoked on destroy state of UI Gadget
*
* @param[in] ug UI gadget object
-* @param[in] service the handler to the service
+* @param[in] app_control the handler to the app_control
* @param[in] priv _priv object
*
* There is no action in this application
*/
-static void _on_destroy(ui_gadget_h ug, service_h service, void *priv)
+static void _on_destroy(ui_gadget_h ug, app_control_h app_control, void *priv)
{
}
@@ -138,14 +138,14 @@ static void _on_destroy(ui_gadget_h ug, service_h service, void *priv)
* Called When an UI gadget received message from its caller ug_send_message()
*
* @param[in] ug UI gadget object
* @param[in] msg the handler to the service
* @param[in] service the handler to the service
* @param[in] priv _priv object
*
* There is no action in this function
*/
-static void _on_message(ui_gadget_h ug, service_h msg,
- service_h service, void *priv)
+static void _on_message(ui_gadget_h ug, app_control_h msg,
+ app_control_h app_control, void *priv)
{
}
@@ -155,11 +155,11 @@ static void _on_message(ui_gadget_h ug, service_h msg,
*
* @param[in] ug UI gadget
* @param[in] event event information
-* @param[in] service the handler to the service
+* @param[in] app_control the handler to the app_control
* @param[in] priv _priv object
*/
static void _on_event(ui_gadget_h ug, enum ug_event event,
- service_h service, void *priv)
+ app_control_h app_control, void *priv)
{
if (!ug || !priv) {
_ERR("Parameter error!");
@@ -138,14 +138,14 @@ static void _on_destroy(ui_gadget_h ug, service_h service, void *priv)
*
* @param[in] ug UI gadget object
-* @param[in] msg the handler to the service
-* @param[in] service the handler to the service
+* @param[in] msg the handler to the app_control
+* @param[in] app_control the handler to the app_control
* @param[in] priv _priv object
*